branch: elpa/aidermacs
commit 1ed5ec220ecf0e5647f34da8502337df808b5572
Author: Kang Tu <kang...@apple.com>
Commit: Kang Tu (aider) <kang...@apple.com>

    feat: update prompts for code command and debug command to reflect new 
functionality
---
 aider.el | 8 ++++----
 1 file changed, 4 insertions(+), 4 deletions(-)

diff --git a/aider.el b/aider.el
index b4d75c6362..94ab272b97 100644
--- a/aider.el
+++ b/aider.el
@@ -146,7 +146,7 @@ COMMAND should be a string representing the command to 
send."
 (defun aider-code-change ()
   "Prompt the user for a command and send it to the corresponding aider comint 
buffer prefixed with \"/code \"."
   (interactive)
-  (let ((command (aider-read-string "Enter code command: ")))
+  (let ((command (aider-read-string "Enter code change requirement: ")))
     (aider-send-command-with-prefix "/code " command)))
 
 ;; New function to get command from user and send it prefixed with "/ask "
@@ -170,17 +170,17 @@ COMMAND should be a string representing the command to 
send."
   (let ((command (aider-read-string "Enter architect command: ")))
     (aider-send-command-with-prefix "/architect " command)))
 
 ;; New function to get command from user and send it prefixed with "/debug "
 (defun aider-debug ()
   "Prompt the user for a command and send it to the corresponding aider comint 
buffer prefixed with \"/debug \",
 replacing all newline characters except for the one at the end."
   (interactive)
-  (let ((command (read-string "Enter debug command: ")))
+  (let ((command (read-string "Enter exception, can be multiple lines: ")))
     ;; Replace all newline characters with a space, except for the last one
     (setq command (replace-regexp-in-string "\n" " " command))
     (when (string-match-p "\n" command)
       (setq command (concat (string-trim command) "\n"))) ;; Add a newline at 
the end
-    (aider--send-command (concat "/debug " command))))
+    (aider--send-command (concat "/ask " command))))
 
 ;; Modified function to get command from user and send it based on selected 
@@ -170,17 +170,17 @@ COMMAND should be a string representing the command to 
     (aider-send-command-with-prefix "/architect " command)))
 
-;; New function to get command from user and send it prefixed with "/debug "
+;; New function to get command from user and send it prefixed with "/ask "
 (defun aider-debug ()
   "Prompt the user for a command and send it to the corresponding aider comint 
region
 (defun aider-undo-last-change ()

Reply via email to